@@ -3,6 +3,8 @@
 #' \code{boot_auto_mrp} estimates uncertainty for auto_mrp via botstrapping.
 #'
 #' @inheritParams auto_MrP
+#' @param pc.names A character vector of the principal component variable names
+#'   in the data.
 
 boot_auto_mrp <- function(y, L1.x, L2.x, mrp.L2.x, L2.unit, L2.reg,
                           L2.x.scale, pcs, folds, bin.proportion,
@@ -10,9 +12,9 @@ boot_auto_mrp <- function(y, L1.x, L2.x, mrp.L2.x, L2.unit, L2.reg,
                           k.folds, cv.sampling, loss.unit, loss.fun,
                           best.subset, lasso, pca, gb, svm, mrp,
                           forward.select, best.subset.L2.x,
-                          lasso.L2.x, pca.L2.x, gb.L2.x, svm.L2.x,
-                          gb.L2.unit, gb.L2.reg, lasso.lambda,
-                          lasso.n.iter, gb.interaction.depth,
+                          lasso.L2.x, pca.L2.x, pc.names, gb.L2.x, svm.L2.x,
+                          svm.L2.unit, svm.L2.reg,gb.L2.unit, gb.L2.reg,
+                          lasso.lambda, lasso.n.iter, gb.interaction.depth,
                           gb.shrinkage, gb.n.trees.init,
                           gb.n.trees.increase, gb.n.trees.max,
                           gb.n.minobsinnode, svm.kernel,
@@ -38,9 +40,9 @@ boot_auto_mrp <- function(y, L1.x, L2.x, mrp.L2.x, L2.unit, L2.reg,
       best.subset = best.subset, lasso = lasso, pca = pca,
       gb = gb, svm = svm, mrp = mrp, forward.select = forward.select,
       best.subset.L2.x = best.subset.L2.x,
-      lasso.L2.x = lasso.L2.x, pca.L2.x = pca.L2.x,
-      gb.L2.x = gb.L2.x, svm.L2.x = svm.L2.x,
-      gb.L2.unit = gb.L2.unit, gb.L2.reg = gb.L2.reg,
+      lasso.L2.x = lasso.L2.x, pca.L2.x = pca.L2.x, pc.names = pc.names,
+      gb.L2.x = gb.L2.x, svm.L2.x = svm.L2.x, svm.L2.unit = svm.L2.unit,
+      svm.L2.reg = svm.L2.reg, gb.L2.unit = gb.L2.unit, gb.L2.reg = gb.L2.reg,
       lasso.lambda = lasso.lambda, lasso.n.iter = lasso.n.iter,
       gb.interaction.depth = gb.interaction.depth,
       gb.shrinkage = gb.shrinkage,
